@@ -2,7 +2,7 @@ using System;
 using System.Collections.Generic;
 using System.Windows.Forms;
 
-namespace Google_SpreadsheetApplication
+namespace Google_YouTubeApplication
 {
     static class Program
     {
