@@ -47,6 +47,9 @@ namespace GoogleAppsMailSettingsDemo
                 // test@domain for the user testUserName and keeps the email.
                 service.UpdateForwarding(testUserName, "true", "test@"+domain, "KEEP");
 
+                // Disable web clip for the user testUserName.
+                service.UpdateWebclip(testUserName, "false");
+
 				// Retrieve forwarding settings for user testUserName
 				AppsExtendedEntry forwarding = service.RetrieveForwarding(testUserName);
 				Console.WriteLine(String.Format("Forwarding to: {0}",
@@ -69,7 +72,7 @@ namespace GoogleAppsMailSettingsDemo
 					imap.getPropertyValueByName("enable")));
 
                 // Activate vacation autoresponse for the user testUserName
-                service.UpdateVacation(testUserName, "true", "vacation", "vacation text...", "true");
+                service.UpdateVacation(testUserName, "true", "vacation", "vacation text...", "false", "true", "2012-01-15", "2012-01-22");
 
 				// Retrieve vacation responder settings for user testUserName
 				AppsExtendedEntry vacation = service.RetrieveVacation(testUserName);
