@@ -21,16 +21,11 @@ using System;
 using System.Xml; 
 using System.Net;
 using System.Diagnostics;
-#if WindowsCE || PocketPC
-#else 
 using System.Runtime.Serialization;
-#endif
 using System.Security.Permissions;
 using System.IO;
 using System.Text; 
 
-
-
 #endregion
 
 
@@ -44,10 +39,7 @@ namespace Google.GData.Client
     /// <summary>standard exception class to be used inside the query object
     /// </summary> 
     //////////////////////////////////////////////////////////////////////
-#if WindowsCE || PocketPC
-#else 
     [Serializable]
-#endif
     public class LoggedException : Exception
     {
 
@@ -82,13 +74,10 @@ namespace Google.GData.Client
         }
         /////////////////////////////////////////////////////////////////////////////
 
-#if WindowsCE || PocketPC
-#else 
         /// <summary>here to please FxCop and maybe for future use</summary> 
         protected LoggedException(SerializationInfo info,  StreamingContext context) : base(info, context)
         {
         }
-#endif
         //////////////////////////////////////////////////////////////////////
         /// <summary>protected void EnsureLogging()</summary> 
         //////////////////////////////////////////////////////////////////////
@@ -101,17 +90,11 @@ namespace Google.GData.Client
     /////////////////////////////////////////////////////////////////////////////
 
 
-
-
-
     //////////////////////////////////////////////////////////////////////
     /// <summary>standard exception class to be used inside the query object
     /// </summary> 
     //////////////////////////////////////////////////////////////////////
-#if WindowsCE || PocketPC
-#else 
     [Serializable]
-#endif
     public class ClientQueryException : LoggedException
     {
         //////////////////////////////////////////////////////////////////////
@@ -138,13 +121,10 @@ namespace Google.GData.Client
         {
         }
 
-#if WindowsCE || PocketPC
-#else 
         /// <summary>here to please FxCop and maybe for future use</summary> 
         protected ClientQueryException(SerializationInfo info,  StreamingContext context) : base(info, context)
         {
         }
-#endif
     }
     /////////////////////////////////////////////////////////////////////////////
 
@@ -153,10 +133,7 @@ namespace Google.GData.Client
     /// <summary>standard exception class to be used inside the feed object
     /// </summary> 
     //////////////////////////////////////////////////////////////////////
-#if WindowsCE || PocketPC
-#else 
     [Serializable]
-#endif
     public class ClientFeedException : LoggedException
     {
 
@@ -183,13 +160,11 @@ namespace Google.GData.Client
         {
         }
         /////////////////////////////////////////////////////////////////////////////
-#if WindowsCE || PocketPC
-#else 
+
         /// <summary>here to please FxCop and maybe for future use</summary> 
         protected ClientFeedException(SerializationInfo info,  StreamingContext context) : base(info, context)
         {
         }
-#endif
     }
     /////////////////////////////////////////////////////////////////////////////
 
@@ -197,13 +172,9 @@ namespace Google.GData.Client
     /// <summary>standard exception class to be used inside the feed object
     /// </summary> 
     //////////////////////////////////////////////////////////////////////
-#if WindowsCE || PocketPC
-#else 
     [Serializable]
-#endif
     public class GDataBatchRequestException : LoggedException
     {
-
         private AtomFeed batchResult;
 
         //////////////////////////////////////////////////////////////////////
@@ -244,13 +215,11 @@ namespace Google.GData.Client
         {
         }
         /////////////////////////////////////////////////////////////////////////////
-#if WindowsCE || PocketPC
-#else 
+
         /// <summary>here to please FxCop and maybe for future use</summary> 
         protected GDataBatchRequestException(SerializationInfo info,  StreamingContext context) : base(info, context)
         {
         }
-#endif
     }
     /////////////////////////////////////////////////////////////////////////////
 
@@ -258,10 +227,7 @@ namespace Google.GData.Client
     /// <summary>standard exception class to be used inside GDataRequest
     /// </summary> 
     //////////////////////////////////////////////////////////////////////
-#if WindowsCE || PocketPC
-#else 
     [Serializable]
-#endif
     public class GDataRequestException : LoggedException
     {
 
@@ -377,25 +343,20 @@ namespace Google.GData.Client
             this.webResponse = response;
         }
         /////////////////////////////////////////////////////////////////////////////
-#if WindowsCE || PocketPC
-#else 
+
         /// <summary>here to please FxCop and maybe for future use</summary> 
         protected GDataRequestException(SerializationInfo info,  StreamingContext context) : base(info, context)
         {
         }
 
-
         /// <summary>overridden to make FxCop happy and future use</summary> 
         [SecurityPermissionAttribute(SecurityAction.Demand, SerializationFormatter=true)]
         public override void GetObjectData( SerializationInfo info,  StreamingContext context ) 
         {
             base.GetObjectData( info, context );
         }
-#endif
     }
     /////////////////////////////////////////////////////////////////////////////
-    
-
 
     //////////////////////////////////////////////////////////////////////
     /// <summary>exception class thrown when we encounter an access denied
