@@ -106,13 +106,9 @@ namespace Google.GData.Calendar
             get
             {
 				bool value;
-#if WindowsCE || PocketPC
-                value = bool.Parse(getCalendarExtensionValue(GDataParserNameTable.XmlHiddenElement));
-#else
 				if (!bool.TryParse(getCalendarExtensionValue(GDataParserNameTable.XmlHiddenElement), out value)) {
 					value = false;
 				}
-#endif
 				return value;
             }
             set
@@ -129,13 +125,9 @@ namespace Google.GData.Calendar
             get
             {
                 bool value;
-#if WindowsCE || PocketPC
-                value = bool.Parse(getCalendarExtensionValue(GDataParserNameTable.XmlSelectedElement));
-#else
 				if (!bool.TryParse(getCalendarExtensionValue(GDataParserNameTable.XmlSelectedElement), out value)) {
 					value = false;
 				}
-#endif
 				return value;
             }
             set
