@@ -198,9 +198,6 @@ namespace Google.GData.Spreadsheets
                 returnEmpty = value;
             }
         }
-
-  #if WindowsCE || PocketPC
-  #else
  
         /// <summary>
         /// Parses an incoming URI string and sets the instance variables
@@ -249,7 +246,7 @@ namespace Google.GData.Spreadsheets
             }
             return this.Uri;
         }
-#endif 
+
         /// <summary>
         /// Resets object state to default, as if newly created.
         /// </summary>
